@@ -1,8 +1,7 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
-//
+
 //  RQuantLib -- R interface to the QuantLib libraries
 //
-//  Copyright (C) 2002 - 2018  Dirk Eddelbuettel 
+//  Copyright (C) 2002 - 2019  Dirk Eddelbuettel
 //  Copyright (C) 2005 - 2006  Dominick Samperi
 //  Copyright (C) 2009 - 2012  Dirk Eddelbuettel and Khanh Nguyen
 //
@@ -36,20 +35,20 @@ QuantLib::Option::Type getOptionType(const std::string &type) {
 }
 
 // cf QuantLib-0.9.0/test-suite/europeanoption.cpp
-boost::shared_ptr<QuantLib::VanillaOption>
-makeOption(const boost::shared_ptr<QuantLib::StrikedTypePayoff>& payoff,
-           const boost::shared_ptr<QuantLib::Exercise>& exercise,
-           const boost::shared_ptr<QuantLib::Quote>& u,
-           const boost::shared_ptr<QuantLib::YieldTermStructure>& q,
-           const boost::shared_ptr<QuantLib::YieldTermStructure>& r,
-           const boost::shared_ptr<QuantLib::BlackVolTermStructure>& vol,
+QuantLib::ext::shared_ptr<QuantLib::VanillaOption>
+makeOption(const QuantLib::ext::shared_ptr<QuantLib::StrikedTypePayoff>& payoff,
+           const QuantLib::ext::shared_ptr<QuantLib::Exercise>& exercise,
+           const QuantLib::ext::shared_ptr<QuantLib::Quote>& u,
+           const QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>& q,
+           const QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>& r,
+           const QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>& vol,
            EngineType engineType,
            QuantLib::Size binomialSteps,
            QuantLib::Size samples) {
 
-    boost::shared_ptr<QuantLib::GeneralizedBlackScholesProcess> stochProcess = makeProcess(u,q,r,vol);
-    boost::shared_ptr<QuantLib::PricingEngine> engine;
-    typedef boost::shared_ptr<QuantLib::PricingEngine> spPE; // shorthand used below
+    QuantLib::ext::shared_ptr<QuantLib::GeneralizedBlackScholesProcess> stochProcess = makeProcess(u,q,r,vol);
+    QuantLib::ext::shared_ptr<QuantLib::PricingEngine> engine;
+    typedef QuantLib::ext::shared_ptr<QuantLib::PricingEngine> spPE; // shorthand used below
 
     switch (engineType) {
     case Analytic:
@@ -96,34 +95,34 @@ makeOption(const boost::shared_ptr<QuantLib::StrikedTypePayoff>& payoff,
     default:
         QL_FAIL("Unknown engine type");
     }
-    boost::shared_ptr<QuantLib::VanillaOption> option(new QuantLib::EuropeanOption(payoff, exercise));
+    QuantLib::ext::shared_ptr<QuantLib::VanillaOption> option(new QuantLib::EuropeanOption(payoff, exercise));
     option->setPricingEngine(engine);
     return option;
 }
 
 // QuantLib option setup utils, copied from the test-suite sources
-boost::shared_ptr<QuantLib::YieldTermStructure> buildTermStructure(Rcpp::List rparam, Rcpp::List tslist) { 
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure> buildTermStructure(Rcpp::List rparam, Rcpp::List tslist) {
 
-    boost::shared_ptr<QuantLib::YieldTermStructure> curve;
+    QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure> curve;
     try {
 
         Rcpp::CharacterVector tsnames = tslist.names();
-        QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"])); 
-        QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"])); 
+        QuantLib::Date todaysDate(Rcpp::as<QuantLib::Date>(rparam["tradeDate"]));
+        QuantLib::Date settlementDate(Rcpp::as<QuantLib::Date>(rparam["settleDate"]));
         // cout << "TradeDate: " << todaysDate << endl << "Settle: " << settlementDate << endl;
-        
+
         RQLContext::instance().settleDate = settlementDate;
         QuantLib::Settings::instance().evaluationDate() = todaysDate;
 
         std::string firstQuoteName = Rcpp::as<std::string>(tsnames[0]);
         //double dt = rparam.getDoubleValue("dt");
-        
+
         std::string interpWhat, interpHow;
         if (firstQuoteName.compare("flat") != 0) { // Get interpolation method (not needed for "flat" case)
             interpWhat = Rcpp::as<std::string>(rparam["interpWhat"]);
             interpHow  = Rcpp::as<std::string>(rparam["interpHow"]);
         }
-        
+
         // initialise from the singleton instance
         QuantLib::Calendar calendar = RQLContext::instance().calendar;
         //Integer fixingDays = RQLContext::instance().fixingDays;
@@ -131,50 +130,50 @@ boost::shared_ptr<QuantLib::YieldTermStructure> buildTermStructure(Rcpp::List rp
         // Any DayCounter would be fine;  ActualActual::ISDA ensures that 30 years is 30.0
         QuantLib::DayCounter termStructureDayCounter = QuantLib::ActualActual(QuantLib::ActualActual::ISDA);
         double tolerance = 1.0e-15;
-        
+
         if (firstQuoteName.compare("flat") == 0) {	// Create a flat term structure.
             double rateQuote = Rcpp::as<double>(tslist[0]);
-            boost::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(rateQuote));
-            boost::shared_ptr<QuantLib::FlatForward> 
+            QuantLib::ext::shared_ptr<QuantLib::Quote> flatRate(new QuantLib::SimpleQuote(rateQuote));
+            QuantLib::ext::shared_ptr<QuantLib::FlatForward>
                 ts(new QuantLib::FlatForward(settlementDate, QuantLib::Handle<QuantLib::Quote>(flatRate), QuantLib::Actual365Fixed()));
             curve =  ts;
         } else {									// Build curve based on a set of observed rates and/or prices.
-            std::vector<boost::shared_ptr<QuantLib::RateHelper> > curveInput;
+            std::vector<QuantLib::ext::shared_ptr<QuantLib::RateHelper> > curveInput;
             for (int i = 0; i < tslist.size(); i++) {
                 std::string name = Rcpp::as<std::string>(tsnames[i]);
                 double val = Rcpp::as<double>(tslist[i]);
-                boost::shared_ptr<QuantLib::RateHelper> rh = ObservableDB::instance().getRateHelper(name, val);
+                QuantLib::ext::shared_ptr<QuantLib::RateHelper> rh = ObservableDB::instance().getRateHelper(name, val);
                 // edd 2009-11-01 FIXME NULL_RateHelper no longer builds under 0.9.9
                 // if (rh == NULL_RateHelper)
                 if (rh.get() == NULL)
                     throw std::range_error("Unknown rate in getRateHelper");
                 curveInput.push_back(rh);
             }
-            boost::shared_ptr<QuantLib::YieldTermStructure> ts =
-                getTermStructure(interpWhat, interpHow, settlementDate, curveInput, 
+            QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure> ts =
+                getTermStructure(interpWhat, interpHow, settlementDate, curveInput,
                                  termStructureDayCounter, tolerance);
             curve = ts;
         }
-        return curve;    
-        
-    } catch(std::exception &ex) { 
-        forward_exception_to_r(ex); 
-    } catch(...) { 
-        ::Rf_error("c++ exception (unknown reason)"); 
+        return curve;
+
+    } catch(std::exception &ex) {
+        forward_exception_to_r(ex);
+    } catch(...) {
+        ::Rf_error("c++ exception (unknown reason)");
     }
 
     return curve;
 }
 
 QuantLib::Schedule getSchedule(Rcpp::List rparam) {
-    
+
     QuantLib::Date effectiveDate(Rcpp::as<QuantLib::Date>(rparam["effectiveDate"]));
-    QuantLib::Date maturityDate(Rcpp::as<QuantLib::Date>(rparam["maturityDate"]));      
+    QuantLib::Date maturityDate(Rcpp::as<QuantLib::Date>(rparam["maturityDate"]));
     QuantLib::Period period = QuantLib::Period(getFrequency(Rcpp::as<double>(rparam["period"])));
     std::string cal = Rcpp::as<std::string>(rparam["calendar"]);
     QuantLib::Calendar calendar;
     if(!cal.empty()) {
-        boost::shared_ptr<QuantLib::Calendar> p = getCalendar(cal);
+        QuantLib::ext::shared_ptr<QuantLib::Calendar> p = getCalendar(cal);
         calendar = *p;
     }
     QuantLib::BusinessDayConvention businessDayConvention =
@@ -191,7 +190,7 @@ QuantLib::Schedule getSchedule(Rcpp::List rparam) {
     if(rparam.containsElementNamed("endOfMonth") ) {
         endOfMonth = (Rcpp::as<double>(rparam["endOfMonth"]) == 1) ? true : false;
     }
-    
+
     QuantLib::Schedule schedule(effectiveDate,
                                 maturityDate,
                                 period,
@@ -203,9 +202,9 @@ QuantLib::Schedule getSchedule(Rcpp::List rparam) {
     return schedule;
 }
 
-boost::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
+QuantLib::ext::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
     Rcpp::List bondparam, std::vector<double> ratesVec, Rcpp::List scheduleparam) {
-    
+
     // get bond parameters
     double settlementDays = Rcpp::as<double>(bondparam["settlementDays"]);
     double faceAmount = Rcpp::as<double>(bondparam["faceAmount"]);
@@ -225,7 +224,7 @@ boost::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
     }
     QuantLib::Calendar paymentCalendar;
     if(bondparam.containsElementNamed("paymentCalendar") ) {
-        boost::shared_ptr<QuantLib::Calendar> p = getCalendar(Rcpp::as<std::string>(bondparam["paymentCalendar"]));
+        QuantLib::ext::shared_ptr<QuantLib::Calendar> p = getCalendar(Rcpp::as<std::string>(bondparam["paymentCalendar"]));
         paymentCalendar = *p;
     }
     QuantLib::Period exCouponPeriod;
@@ -234,7 +233,7 @@ boost::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
     }
     QuantLib::Calendar exCouponCalendar;
     if(bondparam.containsElementNamed("exCouponCalendar") ) {
-        boost::shared_ptr<QuantLib::Calendar> p = getCalendar(Rcpp::as<std::string>(bondparam["exCouponCalendar"]));
+        QuantLib::ext::shared_ptr<QuantLib::Calendar> p = getCalendar(Rcpp::as<std::string>(bondparam["exCouponCalendar"]));
         exCouponCalendar = *p;
     }
     QuantLib::BusinessDayConvention exCouponConvention = QuantLib::Unadjusted;
@@ -245,9 +244,9 @@ boost::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
     if(bondparam.containsElementNamed("exCouponEndOfMonth") ) {
         exCouponEndOfMonth = (Rcpp::as<double>(bondparam["exCouponEndOfMonth"]) == 1) ? true : false;
     }
-    
+
     QuantLib::Schedule schedule = getSchedule(scheduleparam);
-    boost::shared_ptr<QuantLib::FixedRateBond> result(
+    QuantLib::ext::shared_ptr<QuantLib::FixedRateBond> result(
         new QuantLib::FixedRateBond(settlementDays,
                                     faceAmount,
                                     schedule,
@@ -264,36 +263,36 @@ boost::shared_ptr<QuantLib::FixedRateBond> getFixedRateBond(
     return result;
 }
 
-boost::shared_ptr<QuantLib::YieldTermStructure> 
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
 rebuildCurveFromZeroRates(std::vector<QuantLib::Date> dates,
                           std::vector<double> zeros) {
-    boost::shared_ptr<QuantLib::YieldTermStructure>  
-        rebuilt_curve(new QuantLib::InterpolatedZeroCurve<QuantLib::LogLinear>(dates, 
-                                                                               zeros, 
+    QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
+        rebuilt_curve(new QuantLib::InterpolatedZeroCurve<QuantLib::LogLinear>(dates,
+                                                                               zeros,
                                                                                QuantLib::ActualActual()));
     return rebuilt_curve;
 }
 
-boost::shared_ptr<QuantLib::YieldTermStructure> getFlatCurve(Rcpp::List curve) {
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure> getFlatCurve(Rcpp::List curve) {
     QuantLib::Rate riskFreeRate = Rcpp::as<double>(curve["riskFreeRate"]);
-    QuantLib::Date today(Rcpp::as<QuantLib::Date>(curve["todayDate"]));       
-    boost::shared_ptr<QuantLib::SimpleQuote> rRate(new QuantLib::SimpleQuote(riskFreeRate));
+    QuantLib::Date today(Rcpp::as<QuantLib::Date>(curve["todayDate"]));
+    QuantLib::ext::shared_ptr<QuantLib::SimpleQuote> rRate(new QuantLib::SimpleQuote(riskFreeRate));
     QuantLib::Settings::instance().evaluationDate() = today;
     return flatRate(today, rRate, QuantLib::Actual360());
 }
 
-boost::shared_ptr<QuantLib::IborIndex> getIborIndex(Rcpp::List rparam, const QuantLib::Date today) {
+QuantLib::ext::shared_ptr<QuantLib::IborIndex> getIborIndex(Rcpp::List rparam, const QuantLib::Date today) {
     std::string type = Rcpp::as<std::string>(rparam["type"]);
     if (type == "USDLibor"){
         double riskFreeRate = Rcpp::as<double>(rparam["riskFreeRate"]);
         double period = Rcpp::as<double>(rparam["period"]);
-        boost::shared_ptr<QuantLib::SimpleQuote> rRate(new QuantLib::SimpleQuote(riskFreeRate));
+        QuantLib::ext::shared_ptr<QuantLib::SimpleQuote> rRate(new QuantLib::SimpleQuote(riskFreeRate));
         QuantLib::Settings::instance().evaluationDate() = today;
         QuantLib::Handle<QuantLib::YieldTermStructure> curve(flatRate(today, rRate, QuantLib::Actual360()));
-        boost::shared_ptr<QuantLib::IborIndex> iindex(new QuantLib::USDLibor(period * QuantLib::Months, curve));
+        QuantLib::ext::shared_ptr<QuantLib::IborIndex> iindex(new QuantLib::USDLibor(period * QuantLib::Months, curve));
         return iindex;
     }
-    else return boost::shared_ptr<QuantLib::IborIndex>();
+    else return QuantLib::ext::shared_ptr<QuantLib::IborIndex>();
 }
 
 // std::vector<double> getDoubleVector(SEXP vecSexp) {
@@ -304,46 +303,46 @@ boost::shared_ptr<QuantLib::IborIndex> getIborIndex(Rcpp::List rparam, const Qua
 //     }
 // }
 
-boost::shared_ptr<QuantLib::YieldTermStructure>
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
 makeFlatCurve(const QuantLib::Date& today,
-              const boost::shared_ptr<QuantLib::Quote>& forward,
+              const QuantLib::ext::shared_ptr<QuantLib::Quote>& forward,
               const QuantLib::DayCounter& dc) {
-    return boost::shared_ptr<QuantLib::YieldTermStructure>(new QuantLib::FlatForward(today, QuantLib::Handle<QuantLib::Quote>(forward), dc));
+    return QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>(new QuantLib::FlatForward(today, QuantLib::Handle<QuantLib::Quote>(forward), dc));
 }
 
-boost::shared_ptr<QuantLib::YieldTermStructure>
+QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>
 flatRate(const QuantLib::Date& today,
-         const boost::shared_ptr<QuantLib::Quote>& forward,
+         const QuantLib::ext::shared_ptr<QuantLib::Quote>& forward,
          const QuantLib::DayCounter& dc) {
-    return boost::shared_ptr<QuantLib::YieldTermStructure>(new QuantLib::FlatForward(today, QuantLib::Handle<QuantLib::Quote>(forward), dc));
+    return QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>(new QuantLib::FlatForward(today, QuantLib::Handle<QuantLib::Quote>(forward), dc));
 }
-  
-boost::shared_ptr<QuantLib::BlackVolTermStructure> 
+
+QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>
 makeFlatVolatility(const QuantLib::Date& today,
-                   const boost::shared_ptr<QuantLib::Quote>& vol,
+                   const QuantLib::ext::shared_ptr<QuantLib::Quote>& vol,
                    const QuantLib::DayCounter dc) {
-    return boost::shared_ptr<QuantLib::BlackVolTermStructure>(new QuantLib::BlackConstantVol(today, 
-                                                                                             QuantLib::NullCalendar(), 
+    return QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>(new QuantLib::BlackConstantVol(today,
+                                                                                             QuantLib::NullCalendar(),
                                                                                              QuantLib::Handle<QuantLib::Quote>(vol), dc));
 }
 
-boost::shared_ptr<QuantLib::BlackVolTermStructure>
+QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>
 flatVol(const QuantLib::Date& today,
-        const boost::shared_ptr<QuantLib::Quote>& vol,
+        const QuantLib::ext::shared_ptr<QuantLib::Quote>& vol,
         const QuantLib::DayCounter& dc) {
-    return boost::shared_ptr<QuantLib::BlackVolTermStructure>(
-           new QuantLib::BlackConstantVol(today, 
-                                          QuantLib::NullCalendar(), 
+    return QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>(
+           new QuantLib::BlackConstantVol(today,
+                                          QuantLib::NullCalendar(),
                                           QuantLib::Handle<QuantLib::Quote>(vol), dc));
 }
 
 typedef QuantLib::BlackScholesMertonProcess BSMProcess; // shortcut
-boost::shared_ptr<QuantLib::GeneralizedBlackScholesProcess>
-makeProcess(const boost::shared_ptr<QuantLib::Quote>& u,
-            const boost::shared_ptr<QuantLib::YieldTermStructure>& q,
-            const boost::shared_ptr<QuantLib::YieldTermStructure>& r,
-            const boost::shared_ptr<QuantLib::BlackVolTermStructure>& vol) {
-    return boost::shared_ptr<BSMProcess>(new BSMProcess(QuantLib::Handle<QuantLib::Quote>(u),
+QuantLib::ext::shared_ptr<QuantLib::GeneralizedBlackScholesProcess>
+makeProcess(const QuantLib::ext::shared_ptr<QuantLib::Quote>& u,
+            const QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>& q,
+            const QuantLib::ext::shared_ptr<QuantLib::YieldTermStructure>& r,
+            const QuantLib::ext::shared_ptr<QuantLib::BlackVolTermStructure>& vol) {
+    return QuantLib::ext::shared_ptr<BSMProcess>(new BSMProcess(QuantLib::Handle<QuantLib::Quote>(u),
                                                         QuantLib::Handle<QuantLib::YieldTermStructure>(q),
                                                         QuantLib::Handle<QuantLib::YieldTermStructure>(r),
                                                         QuantLib::Handle<QuantLib::BlackVolTermStructure>(vol)));
@@ -355,11 +354,11 @@ makeProcess(const boost::shared_ptr<QuantLib::Quote>& u,
 //     return(d.getJDN() - RcppDate::Jan1970Offset + RcppDate::QLtoJan1970Offset);
 // }
 
-//static const unsigned int QLtoJan1970Offset = 25569;  	// Offset between R / Unix epoch 
+//static const unsigned int QLtoJan1970Offset = 25569;  	// Offset between R / Unix epoch
 
 // // R and Rcpp::Date use the same 'days since epoch' representation; QL uses Excel style
 // int dateFromR(const Rcpp::Date &d) {
-//     static const unsigned int QLtoJan1970Offset = 25569;  	// Offset to R / Unix epoch 
+//     static const unsigned int QLtoJan1970Offset = 25569;  	// Offset to R / Unix epoch
 //     return(d.getDate() + QLtoJan1970Offset);
 // }
 
@@ -381,7 +380,7 @@ QuantLib::DayCounter getDayCounter(const double n){
 #ifdef RQUANTLIB_USE_ACTUAL365NOLEAP
      else if (n==7)
          return QuantLib::Actual365NoLeap();
-#endif    
+#endif
     else if (n==8)
         return QuantLib::ActualActual(QuantLib::ActualActual::ISMA);
     else if (n==9)
@@ -397,13 +396,13 @@ QuantLib::DayCounter getDayCounter(const double n){
 }
 
 QuantLib::BusinessDayConvention getBusinessDayConvention(const double n){
-    if (n==0) 
+    if (n==0)
         return QuantLib::Following;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::ModifiedFollowing;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::Preceding;
-    else if (n==3) 
+    else if (n==3)
         return QuantLib::ModifiedPreceding;
     else if (n==4)
         return QuantLib::Unadjusted;
@@ -411,83 +410,83 @@ QuantLib::BusinessDayConvention getBusinessDayConvention(const double n){
         return QuantLib::HalfMonthModifiedFollowing;
     else if (n==6)
         return QuantLib::Nearest;
-    else  
+    else
         return QuantLib::Unadjusted;
 }
 
 QuantLib::Compounding getCompounding(const double n){
-    if (n==0) 
+    if (n==0)
         return QuantLib::Simple;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::Compounded;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::Continuous;
-    else 
+    else
         return QuantLib::SimpleThenCompounded;
 }
 
 QuantLib::Frequency getFrequency(const double n){
 
-    if (n==-1) 
+    if (n==-1)
         return QuantLib::NoFrequency;
-    else if (n==0) 
+    else if (n==0)
         return QuantLib::Once;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::Annual;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::Semiannual;
-    else if (n==3) 
+    else if (n==3)
         return QuantLib::EveryFourthMonth;
-    else if (n==4) 
+    else if (n==4)
         return QuantLib::Quarterly;
-    else if (n==6) 
+    else if (n==6)
         return QuantLib::Bimonthly;
-    else if (n==12) 
+    else if (n==12)
         return QuantLib::Monthly;
-    else if (n==13) 
+    else if (n==13)
         return QuantLib::EveryFourthWeek;
-    else if (n==26) 
+    else if (n==26)
         return QuantLib::Biweekly;
-    else if (n==52) 
+    else if (n==52)
         return QuantLib::Weekly;
-    else if (n==365) 
+    else if (n==365)
         return QuantLib::Daily;
-    else 
-        return QuantLib::OtherFrequency;   
+    else
+        return QuantLib::OtherFrequency;
 }
 
 QuantLib::Period periodByTimeUnit(int length, std::string unit){
     QuantLib::TimeUnit tu = QuantLib::Years;
-    if (unit=="Days") 
+    if (unit=="Days")
         tu = QuantLib::Days;
-    if (unit=="Weeks") 
+    if (unit=="Weeks")
         tu = QuantLib::Weeks;
-    if (unit=="Months") 
+    if (unit=="Months")
         tu = QuantLib::Months;
     return QuantLib::Period(length, tu);
 }
 
 QuantLib::TimeUnit getTimeUnit(const double n){
-    if (n==0) 
+    if (n==0)
         return QuantLib::Days;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::Weeks;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::Months;
-    else 
+    else
         return QuantLib::Years;
 }
 
 QuantLib::DateGeneration::Rule getDateGenerationRule(const double n){
-    if (n==0) 
+    if (n==0)
         return QuantLib::DateGeneration::Backward;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::DateGeneration::Forward;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::DateGeneration::Zero;
-    else if (n==3) 
+    else if (n==3)
         return QuantLib::DateGeneration::ThirdWednesday;
-    else if (n==4) 
+    else if (n==4)
         return QuantLib::DateGeneration::Twentieth;
     else if (n==5)
         return QuantLib::DateGeneration::TwentiethIMM;
@@ -495,43 +494,43 @@ QuantLib::DateGeneration::Rule getDateGenerationRule(const double n){
         return QuantLib::DateGeneration::OldCDS;
     else if (n==7)
         return QuantLib::DateGeneration::CDS;
-    else 
+    else
         return QuantLib::DateGeneration::TwentiethIMM;
 }
 
-boost::shared_ptr<QuantLib::IborIndex> buildIborIndex(std::string type,
+QuantLib::ext::shared_ptr<QuantLib::IborIndex> buildIborIndex(std::string type,
                                                       const QuantLib::Handle<QuantLib::YieldTermStructure>& iborStrc){
-    if (type == "Euribor10M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor10M(iborStrc));
-    if (type == "Euribor11M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor11M(iborStrc));
-    if (type == "Euribor1M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor1M(iborStrc));
-    if (type == "Euribor1Y") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor1Y(iborStrc));
-    if (type == "Euribor2M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor2M(iborStrc));
-    if (type == "Euribor2W") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor2W(iborStrc));
-    if (type == "Euribor3M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor3M(iborStrc));
-    if (type == "Euribor3W") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor3W(iborStrc));
-    if (type == "Euribor4M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor4M(iborStrc));
-    if (type == "Euribor5M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor5M(iborStrc));
-    if (type == "Euribor6M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor6M(iborStrc));
-    if (type == "Euribor7M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor7M(iborStrc));
-    if (type == "Euribor8M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor8M(iborStrc));
-    if (type == "Euribor9M") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor9M(iborStrc));
-    if (type == "EuriborSW") 
-        return boost::shared_ptr<QuantLib::IborIndex>(new QuantLib::EuriborSW(iborStrc));
-    return boost::shared_ptr<QuantLib::IborIndex>();   
+    if (type == "Euribor10M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor10M(iborStrc));
+    if (type == "Euribor11M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor11M(iborStrc));
+    if (type == "Euribor1M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor1M(iborStrc));
+    if (type == "Euribor1Y")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor1Y(iborStrc));
+    if (type == "Euribor2M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor2M(iborStrc));
+    if (type == "Euribor2W")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor2W(iborStrc));
+    if (type == "Euribor3M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor3M(iborStrc));
+    if (type == "Euribor3W")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor3W(iborStrc));
+    if (type == "Euribor4M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor4M(iborStrc));
+    if (type == "Euribor5M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor5M(iborStrc));
+    if (type == "Euribor6M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor6M(iborStrc));
+    if (type == "Euribor7M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor7M(iborStrc));
+    if (type == "Euribor8M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor8M(iborStrc));
+    if (type == "Euribor9M")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::Euribor9M(iborStrc));
+    if (type == "EuriborSW")
+        return QuantLib::ext::shared_ptr<QuantLib::IborIndex>(new QuantLib::EuriborSW(iborStrc));
+    return QuantLib::ext::shared_ptr<QuantLib::IborIndex>();
 }
 
 Rcpp::DataFrame getCashFlowDataFrame(const QuantLib::Leg &bondCashFlow) {
@@ -558,20 +557,20 @@ QuantLib::DividendSchedule getDividendSchedule(Rcpp::DataFrame divScheDF) {
         Rcpp::NumericVector n3v = divScheDF[3];
         int nrow = s0v.size();
 
-        for (int row=0; row<nrow; row++){          
+        for (int row=0; row<nrow; row++){
             int type = (s0v[row] == "Fixed") ? 1 : 0; //  (table[row][0].getStringValue()=="Fixed") ? 1 : 0;
             double amount = n1v[row]; // table[row][1].getDoubleValue();
             double rate = n2v[row]; // table[row][2].getDoubleValue();
             Rcpp::Date rd = Rcpp::Date(n3v[row]);
-            QuantLib::Date d(Rcpp::as<QuantLib::Date>(Rcpp::wrap(rd))); //table[row][3].getDateValue()));            
+            QuantLib::Date d(Rcpp::as<QuantLib::Date>(Rcpp::wrap(rd))); //table[row][3].getDateValue()));
             if (type==1) {
-                dividendSchedule.push_back(boost::shared_ptr<QuantLib::Dividend>(new QuantLib::FixedDividend(amount, d)));
+                dividendSchedule.push_back(QuantLib::ext::shared_ptr<QuantLib::Dividend>(new QuantLib::FixedDividend(amount, d)));
             } else {
-                dividendSchedule.push_back(boost::shared_ptr<QuantLib::Dividend>(new QuantLib::FractionalDividend(rate, amount, d)));
+                dividendSchedule.push_back(QuantLib::ext::shared_ptr<QuantLib::Dividend>(new QuantLib::FractionalDividend(rate, amount, d)));
             }
         }
-    } catch (std::exception& ex) { 
-        forward_exception_to_r(ex); 
+    } catch (std::exception& ex) {
+        forward_exception_to_r(ex);
     }
     return dividendSchedule;
 }
@@ -594,29 +593,29 @@ QuantLib::CallabilitySchedule getCallabilitySchedule(Rcpp::DataFrame callScheDF)
             Rcpp::Date rd = Rcpp::Date(n2v[row]);
             QuantLib::Date d(Rcpp::as<QuantLib::Date>(Rcpp::wrap(rd)));
             if (type==1){
-                callabilitySchedule.push_back(boost::shared_ptr<QuantLib::Callability>
-                                              (new QuantLib::Callability(QuantLib::Callability::Price(price, 
+                callabilitySchedule.push_back(QuantLib::ext::shared_ptr<QuantLib::Callability>
+                                              (new QuantLib::Callability(QuantLib::Callability::Price(price,
                                                                                                       QuantLib::Callability::Price::Clean),
                                                                          QuantLib::Callability::Put,d )));
             } else {
-                callabilitySchedule.push_back(boost::shared_ptr<QuantLib::Callability>
-                                              (new QuantLib::Callability(QuantLib::Callability::Price(price, 
+                callabilitySchedule.push_back(QuantLib::ext::shared_ptr<QuantLib::Callability>
+                                              (new QuantLib::Callability(QuantLib::Callability::Price(price,
                                                                                                       QuantLib::Callability::Price::Clean),
                                                                          QuantLib::Callability::Call,d )));
-            }            
+            }
         }
     } catch (std::exception& ex){
-        forward_exception_to_r(ex); 
+        forward_exception_to_r(ex);
     }
     return callabilitySchedule;
 }
 
 QuantLib::Duration::Type getDurationType(const double n) {
-    if (n==0) 
+    if (n==0)
         return QuantLib::Duration::Simple;
-    else if (n==1) 
+    else if (n==1)
         return QuantLib::Duration::Macaulay;
-    else if (n==2) 
+    else if (n==2)
         return QuantLib::Duration::Modified;
     else {
         throw std::range_error("Invalid duration type " + boost::lexical_cast<std::string>(n));
@@ -624,7 +623,7 @@ QuantLib::Duration::Type getDurationType(const double n) {
 }
 
 //' This function returns the QuantLib version string as encoded in the header
-//' file \code{config.hpp} and determined at compilation time of the QuantLib library. 
+//' file \code{config.hpp} and determined at compilation time of the QuantLib library.
 //'
 //' @title Return the QuantLib version number
 //' @return A character variable
@@ -638,7 +637,7 @@ std::string getQuantLibVersion() {
 }
 
 //' This function returns a named vector of boolean variables describing several
-//' configuration options determined at compilation time of the QuantLib library. 
+//' configuration options determined at compilation time of the QuantLib library.
 //'
 //' Not all of these features are used (yet) by RQuantLib.
 //' @title Return configuration options of the QuantLib library
@@ -653,7 +652,7 @@ Rcpp::LogicalVector getQuantLibCapabilities() {
         hasHighResolutionDate=false,    // supported as of RQuantLib 0.4.2
         hasNegativeRates=false;         // not explicitly supported or denied
 
-#ifdef QL_ENABLE_SESSIONS    
+#ifdef QL_ENABLE_SESSIONS
     hasSessions = true;
 #endif
 
